@@ -1,7 +1,7 @@
-from helpers.http_calls import HttpCalls
+from zscaler_helpers.http_calls import HttpCalls
 
 
-class ZpaTalkerPublic(object):
+class ZpaTalker(object):
     """
     ZPA API talker
     Documentation: https://help.zscaler.com/zpa/zpa-api/api-developer-reference-guide
@@ -45,7 +45,9 @@ class ZpaTalkerPublic(object):
 
     def authenticate(self, client_id, client_secret):
         """
-        Method to obtain the Bearer Token
+        Method to obtain the Bearer Token. Refer to https://help.zscaler.com/zpa/adding-api-keys
+        :param client_id: type string. client id
+        :param client_secret. type string. client secret
         return token
         """
         url = f'/signin'
@@ -136,6 +138,22 @@ class ZpaTalkerPublic(object):
         response = self.hp_http.post_call(url=url, payload=payload, headers=self.header, error_handling=True)
         return response.json()
 
+    def update_application_segment(self,applicationId,payload):
+        """
+        Updates the Application Segment details for the specified ID
+        :param applicationId: type int. Application ID
+        """
+        url = f"/mgmtconfig/v1/admin/customers/{self.customerId}/application/{applicationId}"
+        response = self.hp_http.put_call(url=url, payload=payload, headers=self.header, error_handling=True)
+        return response
+    def delete_application_segment(self,applicationId,):
+        """
+        Updates the Application Segment details for the specified ID
+        :param applicationId: type int. Application ID
+        """
+        url = f"/mgmtconfig/v1/admin/customers/{self.customerId}/application/{applicationId}"
+        response = self.hp_http.delete_call(url=url, error_handling=True)
+        return response
     # segment-group-controller
 
     def list_segment_group(self, segmentGroupId=None, query=False):
@@ -150,8 +168,7 @@ class ZpaTalkerPublic(object):
         else:
             if not query:
                 query = '?pagesize=500'
-            url = f'/mgmtconfig/v1/admin/customers/{self.customerId}/segmentGroup/{query}'
-
+            url = f'/mgmtconfig/v1/admin/customers/{self.customerId}/segmentGroup{query}'
         response = self.hp_http.get_call(url, headers=self.header, error_handling=True)
         return response.json()
 
@@ -319,7 +336,7 @@ class ZpaTalkerPublic(object):
     # scim-group-controller
     def list_scim_groups(self, idpId, query=False):
         """
-        Method details for all SCIM groups
+        Method to list all SCIM groups
         :param idpId: The unique identifies of the Idp
         :param query: ?page=1&pagesize=20&search=consequat
         """
@@ -480,3 +497,15 @@ class ZpaTalkerPublic(object):
             if srap is not None:
                 sralist.extend(srap)
         return sralist
+
+    # Certificate Controller v2
+    def list_issued_certificates(self, query=None):
+        """
+        Method to get all issued certificates
+        """
+        if not query:
+            query = '?pagesize=500'
+
+        url = f'/mgmtconfig/v2/admin/customers/{self.customerId}/certificate/issued'
+        response = self._obtain_all_results(url)
+        return response
